"use strict";
// Copyright (c) Samuel Gratzl.
// Distributed under the terms of the MIT License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaggleView = exports.LineUpView = exports.ALineUpView = exports.TaggleModel = exports.LineUpModel = void 0;
const base_1 = require("@jupyter-widgets/base");
const lineupjs_1 = require("lineupjs");
require("./style.css");
const utils_1 = require("./utils");
const version_1 = require("./version");
const fields = {
    _data: [],
    _columns: [],
    options: {},
    rankings: [],
    value: []
};
class LineUpModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign(Object.assign({}, super.defaults()), { _model_name: LineUpModel.model_name, _model_module: LineUpModel.model_module, _model_module_version: LineUpModel.model_module_version, _view_name: LineUpModel.view_name, _view_module: LineUpModel.view_module, _view_module_version: LineUpModel.view_module_version }), fields);
    }
}
exports.LineUpModel = LineUpModel;
LineUpModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
LineUpModel.model_name = 'LineUpModel';
LineUpModel.model_module = 'lineup_widget';
LineUpModel.model_module_version = version_1.JUPYTER_EXTENSION_VERSION;
LineUpModel.view_name = 'LineUpView'; // Set to null if no view
LineUpModel.view_module = 'lineup_widget'; // Set to null if no view
LineUpModel.view_module_version = version_1.JUPYTER_EXTENSION_VERSION;
class TaggleModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign(Object.assign({}, super.defaults()), { _model_name: TaggleModel.model_name, _model_module: TaggleModel.model_module, _model_module_version: TaggleModel.model_module_version, _view_name: TaggleModel.view_name, _view_module: TaggleModel.view_module, _view_module_version: TaggleModel.view_module_version }), fields);
    }
}
exports.TaggleModel = TaggleModel;
TaggleModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
TaggleModel.model_name = 'TaggleModel';
TaggleModel.model_module = LineUpModel.model_module;
TaggleModel.model_module_version = version_1.JUPYTER_EXTENSION_VERSION;
TaggleModel.view_name = 'TaggleView'; // Set to null if no view
TaggleModel.view_module = LineUpModel.view_module; // Set to null if no view
TaggleModel.view_module_version = version_1.JUPYTER_EXTENSION_VERSION;
class ALineUpView extends base_1.DOMWidgetView {
    render() {
        this.data = this.createData();
        this.model.on('change:_data', this.dataChanged, this);
        this.data.setSelection(this.model.get('value'));
        this.model.on('change:value', this.selectionChanged, this);
        this.data.on('selectionChanged', (selection) => {
            this.model.set('value', selection, { updated_view: this });
            this.touch();
        });
        this.createRankings();
        const options = this.model.get('options');
        this.lineup = this.createLineUp(Object.assign(Object.assign({}, options), { panel: options.sidePanel !== false, panelCollapsed: options.sidePanel === 'collapsed' }));
    }
    createData() {
        const options = this.model.get('options');
        const rows = this.model.get('_data');
        const columns = this.model.get('_columns');
        return new lineupjs_1.LocalDataProvider(rows, lineupjs_1.deriveColors(columns), {
            filterGlobally: options.filterGlobally,
            singleSelection: options.singleSelection
        });
    }
    dataChanged() {
        this.data.clearColumns();
        const rows = this.model.get('_data');
        const columns = this.model.get('_columns');
        lineupjs_1.deriveColors(columns).forEach((desc) => this.data.pushDesc(desc));
        this.data.setData(rows);
        this.createRankings();
    }
    createRankings() {
        this.data.clearRankings();
        const rankings = this.model.get('rankings');
        if (rankings.length === 0) {
            this.data.deriveDefault();
        }
        else {
            rankings.forEach((ranking) => utils_1.pushRanking(this.data, ranking));
        }
    }
    selectionChanged() {
        this.data.setSelection(this.model.get('value'));
    }
}
exports.ALineUpView = ALineUpView;
class LineUpView extends ALineUpView {
    createLineUp(options) {
        return new lineupjs_1.LineUp(this.el, this.data, options);
    }
}
exports.LineUpView = LineUpView;
class TaggleView extends ALineUpView {
    createLineUp(options) {
        return new lineupjs_1.Taggle(this.el, this.data, options);
    }
}
exports.TaggleView = TaggleView;
//# sourceMappingURL=widget.js.map